==> mozc-2.17.2313.102.tar.xz: mozc-2.17.2313.102/src/gui/administration_dialog/administration_dialog.h <==
// Copyright 2010-2016, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

#ifndef MOZC_GUI_ADMINISTRATION_DIALOG_H_
#define MOZC_GUI_ADMINISTRATION_DIALOG_H_

#include <QtGui/QtGui>
#include <QtGui/QDialog>
#include <string>
#include "gui/administration_dialog/ui_administration_dialog.h"

namespace mozc {
namespace gui {
class AdministrationDialog : public QDialog,
                             private Ui::AdministrationDialog {
  Q_OBJECT;

 public:
  AdministrationDialog();
  virtual ~AdministrationDialog();

 protected slots:
  virtual void clicked(QAbstractButton *button);

 protected:
  bool eventFilter(QObject *obj, QEvent *event);

 private:
  bool CanStartService();
};
}  // namespace mozc::gui
}  // namespace mozc
#endif  // MOZC_GUI_ADMINISTRATION_DIALOG_H_

==> mozc_2.26.4220.100+dfsg.orig.tar.xz: mozc-2.26.4220.100+dfsg/src/gui/administration_dialog/administration_dialog.h <==
// Copyright 2010-2020, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

#ifndef MOZC_GUI_ADMINISTRATION_DIALOG_ADMINISTRATION_DIALOG_H_
#define MOZC_GUI_ADMINISTRATION_DIALOG_ADMINISTRATION_DIALOG_H_

#include <QtGui/QtGui>
#include <QtWidgets/QDialog>

#include "gui/administration_dialog/ui_administration_dialog.h"

namespace mozc {
namespace gui {
class AdministrationDialog : public QDialog, private Ui::AdministrationDialog {
  Q_OBJECT;

 public:
  AdministrationDialog();
  ~AdministrationDialog() override;

 protected slots:
  virtual void clicked(QAbstractButton *button);

 protected:
  bool eventFilter(QObject *obj, QEvent *event) override;

 private:
  bool CanStartService();
  QString dialog_title_;
};
}  // namespace gui
}  // namespace mozc
#endif  // MOZC_GUI_ADMINISTRATION_DIALOG_ADMINISTRATION_DIALOG_H_
